@@ -4,5 +4,5 @@ from hellogrpc.hellogrpc_pb2 import *
 from hellogrpc.hellogrpc_pb2_grpc import *
 
 def Client():
-    with grpc.insecure_channel('localhost:50051') as channel:
-        return GreeterStub(channel)
+    channel = grpc.secure_channel('hello.rpc.stackmachine.com:443')
+    return GreeterStub(channel)
